# ocx-common
> ### A python package

A python package with common classes and functions used across several projects

## Installation

install from pypi:
````commandline
pip install ocx_common
````

## API

The API documentation is autogenerated using ``sphinx`` and the Read The Docs theme:

https://ocxstandard.github.io/ocx-common/
